@@ -63,7 +63,7 @@ hxrd.Ang2Q.init_linear('z-',center_ch,1500.,chpdeg=chpdeg,roi=roi)
 # since reading is much faster from HDF5 once the data are transformed
 h5file = os.path.join("data",sample+".h5")
 try: s  # try if spec file object already exist from a previous run of the script ("run -i" in ipython)
-except NameError: s = xu.io.SPECFile(sample+".spec",path="data")
+except NameError: s = xu.io.SPECFile(sample+".spec.bz2",path="data")
 else: s.Update()
 s.Save2HDF5(h5file)
 
@@ -89,7 +89,7 @@ omalign,ttalign,p,cov = xu.analysis.fit_bragg_peak(om,tt,psd,omalign,ttalign,hxr
 # calculate data on a regular grid of 200x201 points
 gridder = xu.Gridder2D(200,201)
 gridder(qy,qz,psd)
-INT = xu.maplog(gridder.gdata.transpose(),8.5,0)
+INT = xu.maplog(gridder.data.transpose(),8.5,0)
 
 # plot the intensity as contour plot
 plt.figure(); plt.clf()
@@ -125,7 +125,7 @@ omalign,ttalign,p,cov = xu.analysis.fit_bragg_peak(om,tt,psd,omalign,ttalign,hxr
 gridder = xu.Gridder2D(400,600)
 gridder(qy,qz,psd)
 # calculate intensity which should be plotted
-INT = xu.maplog(gridder.gdata.transpose(),8.5,0)
+INT = xu.maplog(gridder.data.transpose(),8.5,0)
 
 # plot the intensity as contour plot
 plt.figure(); plt.clf()
