@@ -35,6 +35,7 @@ import tables
 import gzip
 
 # relative imports from xrayutilities
+from .helper import xu_open
 from .. import config
 from ..exception import InputError
 
@@ -147,7 +148,7 @@ class SPECScan(object):
             # ASSUME ORDER DID NOT CHANGE!! (which might be wrong)
             # in fact this is sign for a broken spec file
             # number of initial motor positions should not change without new file header!
-            for i in range(len(imopnames)):
+            for i in range(min(len(imopnames),len(imopvalues))):
                 self.init_motor_pos["INIT_MOPO_"+imopnames[i].replace(" ","_").replace("-","_").replace(".","_")] = float(imopvalues[i])
             # read the rest of the positions into dummy INIT_MOPO__NONAME__%03d
             for i in range(len(imopnames),len(imopvalues)):
@@ -552,10 +553,7 @@ class SPECFile(object):
         self.scan_list = []
         #open the file for reading
         try:
-            if os.path.splitext(self.full_filename)[-1] == '.gz':
-                self.fid = gzip.open(self.full_filename,"rb")
-            else :
-                self.fid = open(self.full_filename,"rb")
+            self.fid=xu_open(self.full_filename)
             self.last_offset = self.fid.tell()
         except:
             self.fid = None
@@ -609,9 +607,9 @@ class SPECFile(object):
             raise InputError("h5f argument of wrong type was passed")
 
         try:
-            g = h5.createGroup("/",os.path.splitext(self.filename)[0],"Data of SPEC - File %s" %(self.filename))
+            g = h5.createGroup("/",os.path.splitext(os.path.splitext(self.filename)[0])[0],"Data of SPEC - File %s" %(self.filename))
         except:
-            g = h5.getNode("/"+os.path.splitext(self.filename)[0])
+            g = h5.getNode("/"+os.path.splitext(os.path.splitext(self.filename)[0])[0])
 
         for s in self.scan_list:
             if (((not g.__contains__(s.name)) or s.ischanged) and s.scan_status!="NODATA"):
@@ -632,10 +630,7 @@ class SPECFile(object):
 
         self.fid.close()
         try:
-            if os.path.splitext(self.full_filename)[-1] == '.gz':
-                self.fid = gzip.open(self.full_filename,"rb")
-            else :
-                self.fid = open(self.full_filename,"rb")
+            self.fid=xu_open(self.full_filename)
         except:
             self.fid = None
             raise IOError("error opening SPEC file %s" %(self.full_filename))
@@ -722,8 +717,10 @@ class SPECFile(object):
                 line_buffer = SPEC_initmopopos.sub("",line_buffer)
                 line_buffer = line_buffer.strip()
                 line_list = SPEC_multi_blank.split(line_buffer)
-                for value in line_list:
-                    init_motor_values.append(float(value))
+                try: # sometimes initial motor position are simply empty and this should not lead to an error
+                    for value in line_list:
+                        init_motor_values.append(float(value))
+                except: pass
 
             #if the line contains the number of colunmns
             elif SPEC_nofcols.match(line_buffer) and scan_started:
@@ -879,10 +876,7 @@ class SPECLog(object):
         self.full_filename = os.path.join(path,self.filename)
 
         try:
-            if os.path.splitext(self.full_filename)[-1] == '.gz':
-                self.fid = gzip.open(self.full_filename,"r")
-            else :
-                self.fid = open(self.full_filename,"r")
+            self.fid = xu_open(self.full_filename,'r')
         except:
             raise IOError("cannot open log file %s" %(self.full_filename))
 
