@@ -43,6 +43,9 @@ extern PyObject* ang2q_conversion_area(PyObject *self, PyObject *args);
 extern PyObject* ang2q_conversion_area_pixel(PyObject *self, PyObject *args);
 extern PyObject* ang2q_conversion_area_pixel2(PyObject *self, PyObject *args);
 
+/* functions from file_io.c */
+extern PyObject* cbfread(PyObject *self, PyObject *args);
+
 static PyMethodDef XRU_Methods[] = {
     {"block_average1d",  (PyCFunction)block_average1d, METH_VARARGS,
      "block average for one-dimensional numpy double array\n\n"
@@ -53,7 +56,7 @@ static PyMethodDef XRU_Methods[] = {
      "Returns\n"
      "-------\n"
      " block_av:   block averaged output array\n"
-     "             size = ceil(N/Nav) \n" 
+     "             size = ceil(N/Nav) \n"
     },
     {"block_average2d",  block_average2d, METH_VARARGS,
      "2D block average for one CCD frame\n\n"
@@ -68,7 +71,7 @@ static PyMethodDef XRU_Methods[] = {
      "Returns\n"
      "-------\n"
      " block_av:     block averaged output array\n"
-     "               size = (ceil(Nch2/Nav2) , ceil(Nch1/Nav1))\n"   
+     "               size = (ceil(Nch2/Nav2) , ceil(Nch1/Nav1))\n"
     },
     {"block_average_PSD",  block_average_PSD, METH_VARARGS,
      "1D block average for a bunch of PSD spectra in a 2D array\n"
@@ -84,8 +87,8 @@ static PyMethodDef XRU_Methods[] = {
      " block_av:    block averaged output array\n"
      "              size = (Nspec , ceil(Nch/Nav)) (out)\n"
     },
-    {"gridder2d",pygridder2d,METH_VARARGS, 
-     "Function performs 2D gridding on 1D input data. \n\n" 
+    {"gridder2d",pygridder2d,METH_VARARGS,
+     "Function performs 2D gridding on 1D input data. \n\n"
      "Parameters\n"
      "----------\n"
      "  x ...... input x-values (1D numpy array - float64)\n"
@@ -99,8 +102,8 @@ static PyMethodDef XRU_Methods[] = {
      "  ymax ... minimum y-value of the grid\n"
      "  out .... output data\n"
     },
-    {"gridder3d",pygridder3d,METH_VARARGS, 
-     "Function performs 2D gridding on 1D input data. \n\n" 
+    {"gridder3d",pygridder3d,METH_VARARGS,
+     "Function performs 2D gridding on 1D input data. \n\n"
      "Parameters\n"
      "----------\n"
      "  x ...... input x-values (1D numpy array - float64)\n"
@@ -161,7 +164,7 @@ static PyMethodDef XRU_Methods[] = {
      "Returns\n"
      "-------\n"
      " qpos ............ momentum transfer (Npoints*Nch,3)\n"
-     " \n"     
+     " \n"
     },
     {"ang2q_conversion_area", ang2q_conversion_area, METH_VARARGS,
      "conversion of Npoints of goniometer positions to reciprocal space\n"
@@ -192,7 +195,7 @@ static PyMethodDef XRU_Methods[] = {
      "Returns\n"
      "-------\n"
      " qpos ............ momentum transfer (Npoints*Npix1*Npix2,3)\n"
-     "\n"     
+     "\n"
     },
     {"ang2q_conversion_area_pixel", ang2q_conversion_area_pixel, METH_VARARGS,
      "conversion of Npoints of detector positions to Q\n"
@@ -258,6 +261,16 @@ static PyMethodDef XRU_Methods[] = {
      "-------\n"
      " qpos ............ momentum transfer (Npoints,3)\n"
     },
+    {"cbfread", cbfread, METH_VARARGS,
+     "parser for cbf data arrays from Pilatus detector images\n\n"
+     " Parameters\n"
+     " ----------\n"
+     "  data:   data stream (character array)\n"
+     "  nx,ny:  number of entries of the two dimensional image\n\n"
+     " Returns\n"
+     " -------\n"
+     "  the parsed data values as float ndarray\n"
+    },
     {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
@@ -280,7 +293,7 @@ PyMODINIT_FUNC
 #if PY_MAJOR_VERSION >= 3
 PyInit_cxrayutilities(void)
 #else
-initcxrayutilities(void) 
+initcxrayutilities(void)
 #endif
 {
     PyObject *m;
@@ -288,7 +301,7 @@ initcxrayutilities(void)
     #if PY_MAJOR_VERSION >= 3
     m = PyModule_Create(&moduledef);
     #else
-    m = Py_InitModule3("cxrayutilities", XRU_Methods, 
+    m = Py_InitModule3("cxrayutilities", XRU_Methods,
         "Python C extension including performance critical parts\n"
         "of xrayutilities (gridder, qconversion, block-averageing)\n");
     #endif
